server_client_20150129_151959

### config1

Total tests | Passed | Failed | Skipped | Start time | End time | Execution time | Naarad
--- | --- | --- | --- | --- | --- | --- | ---
0 | 0 | 0 | 0 | 2015-01-29 15:20:01 | 2015-01-29 15:20:03 | 2.24404907227 sec | Report

Messages: setup_suite() failed. See below for the trace. Traceback (most recent call last): File "/Users/jehrlich/workspace/venv/lib/python2.7/site-packages/zopkio-0.1.10-py2.7.egg/zopkio/test_runner.py", line 107, in run self.deployment_module.setup_suite() File "examples/server_client/deployment.py", line 59, in setup_suite "args": "localhost 8000".split()}) File "/Users/jehrlich/workspace/venv/lib/python2.7/site-packages/zopkio-0.1.10-py2.7.egg/zopkio/deployer.py", line 78, in deploy self.start(unique_id, configs) File "/Users/jehrlich/workspace/venv/lib/python2.7/site-packages/zopkio-0.1.10-py2.7.egg/zopkio/adhoc_deployer.py", line 187, in start chan = exec_with_env(ssh, command, msg="Failed to start", env=env, sync=configs.get('sync', False)) File "/Users/jehrlich/workspace/venv/lib/python2.7/site-packages/zopkio-0.1.10-py2.7.egg/zopkio/remote_host_helper.py", line 84, in exec_with_env new_command = bash_profile_command + env_command + command TypeError: cannot concatenate 'str' and 'NoneType' objects